darkhistory.low\_energy.lowE\_deposition
========================================

.. automodule:: darkhistory.low_energy.lowE_deposition

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree: lowE_deposition
   
      compute_fs
   
   

   
   
   

   
   
   